==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/network/ServerNetworking.java <==
package tocraft.walkers.network;

import dev.architectury.networking.NetworkManager;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_3222;
import tocraft.walkers.ability.AbilityRegistry;
import tocraft.walkers.api.PlayerAbilities;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.network.impl.SwapPackets;
import tocraft.walkers.network.impl.SwapVariantPackets;
import tocraft.walkers.network.impl.UnlockPackets;

public class ServerNetworking implements NetworkHandler {

    public static void initialize() {
        SwapPackets.registerWalkersRequestPacketHandler();
        UnlockPackets.registerShapeUnlockRequestPacketHandler();
        SwapVariantPackets.registerSwapVariantPacketHandler();
        registerUseAbilityPacketHandler();
    }

    @SuppressWarnings("ConstantConditions")
    private static void registerUseAbilityPacketHandler() {
        NetworkManager.registerReceiver(NetworkManager.Side.C2S, USE_ABILITY, (buf, context) -> {
            class_1657 player = context.getPlayer();

            context.getPlayer().method_5682().execute(() -> {
                class_1309 shape = PlayerShape.getCurrentShape(player);

                // Verify we should use ability for the player's current shape
                if (shape != null) {
                    if (AbilityRegistry.has(shape)) {
                        // Check cooldown
                        if (PlayerAbilities.canUseAbility(player)) {
                            AbilityRegistry.get(shape).onUse(player, shape, context.getPlayer().method_37908());
                            PlayerAbilities.setCooldown(player, AbilityRegistry.get(shape).getCooldown(shape));
                            PlayerAbilities.sync((class_3222) player);
                        }
                    }
                }
            });
        });
    }
}

==> walkers-fabric-1.20.1-5.3.1-sources.jar: tocraft/walkers/network/ServerNetworking.java <==
package tocraft.walkers.network;

import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_3222;
import tocraft.craftedcore.event.common.PlayerEvents;
import tocraft.craftedcore.network.ModernNetworking;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.ability.AbilityRegistry;
import tocraft.walkers.api.PlayerAbilities;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.network.impl.SwapPackets;
import tocraft.walkers.network.impl.SwapVariantPackets;
import tocraft.walkers.network.impl.SyncApiLevelPackets;
import tocraft.walkers.network.impl.UnlockPackets;

public class ServerNetworking implements NetworkHandler {

    public static void initialize() {
        SwapPackets.registerWalkersRequestPacketHandler();
        UnlockPackets.registerShapeUnlockRequestPacketHandler();
        SwapVariantPackets.registerSwapVariantPacketHandler();
        registerUseAbilityPacketHandler();

        //#if MC>=1205
        ModernNetworking.registerType(SHAPE_SYNC);
        ModernNetworking.registerType(ABILITY_SYNC);
        ModernNetworking.registerType(UNLOCK_SYNC);
        ModernNetworking.registerType(CHANGE_VEHICLE_STATE);
        ModernNetworking.registerType(SYNC_API_LEVEL);
        //#endif

        PlayerEvents.PLAYER_JOIN.register(SyncApiLevelPackets::sendSyncPacket);
    }

    @SuppressWarnings("ConstantConditions")
    private static void registerUseAbilityPacketHandler() {
        ModernNetworking.registerReceiver(ModernNetworking.Side.C2S, USE_ABILITY, (context, packet) -> {
            class_1657 player = context.getPlayer();

            context.getPlayer().method_5682().execute(() -> {
                class_1309 shape = PlayerShape.getCurrentShape(player);

                // Verify we should use ability for the player's current shape
                if (shape != null) {
                    if (AbilityRegistry.has(shape)) {
                        // Check cooldown
                        if (PlayerAbilities.canUseAbility(player)) {
                            AbilityRegistry.get(shape).onUse(player, shape, CEntity.level(context.getPlayer()));
                            PlayerAbilities.setCooldown(player, AbilityRegistry.get(shape).getCooldown(shape));
                            PlayerAbilities.sync((class_3222) player);
                        }
                    }
                }
            });
        });
    }
}
